@echo on
goto start
@rem **************************************************************************
@rem * Licensed Materials - Property of Tivoli Systems
@rem * 5697-B82
@rem * (C) Copyright Tivoli Systems 2001
@rem * All rights reserved.
@rem *
@rem * US Government Users Restricted Rights - Use, duplication or
@rem * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@rem **************************************************************************
:usage

@echo Usage
@echo -----
@echo %SCRIPT% port name [ args ] 
@echo.
@echo Purpose
@echo -------
@echo Initiate a "Locate Resource" request to the NMC Console Web Server
@echo running on the same machine.  If necessary, the NMC Console is started.
@echo.
@echo Arguments
@echo ---------
@echo port - required; NMC console web server port number
@echo                            8080    = specific port number
@echo name - required; name of resource to locate
@echo args - optional; additional TCONSOLE script command line arguments used 
@echo                  if the NMC console must be started
@echo.
@echo Required NMC Environment Variables
@echo ----------------------------------
@echo NV390_TCONSOLE_INSTALL_ROOT...installation root path [%NV390_TCONSOLE_INSTALL_ROOT%]
@echo NV390_TCONSOLE_SCRIPT.........console start script   [%NV390_TCONSOLE_SCRIPT%]

goto done

:start
cls
setlocal

set SCRIPT=%0

set ORIG_TCONSOLE_JAVAOPTS=%TCONSOLE_JAVAOPTS%
          
@rem **************************************************************************
@rem *  DEBUG controls if internal debugging info is displayed
@rem *  
@rem *  to disable, use: set DEBUG=
@rem **************************************************************************
set DEBUG=-Dverbose

@rem **************************************************************************
@rem *  Parse command line argument 1 ==> port number
@rem **************************************************************************
if     "%1"=="" goto usage
set PORT=%1
shift

@rem **************************************************************************
@rem *  Parse command line argument 2 ==> resource name
@rem **************************************************************************
if "%1"=="" goto usage
set RES=%1
shift

@rem **************************************************************************
@rem *  Parse command line argument 3..n ==> TCONSOLE command line arg(s)
@rem **************************************************************************
set ARGS=

:nextArg
@if "%1"=="" goto argsDone

set ARGS=%ARGS% %1
shift

@goto nextArg

:argsDone

@echo PORT: "%PORT%"
@echo  RES: "%RES%"
@echo ARGS: "%ARGS%"

@rem **************************************************************************
@rem *  Move to the NMC's BIN directory
@rem **************************************************************************
cd                                                               
cd /d %NV390_TCONSOLE_INSTALL_ROOT%\generic_unix\TDS\client\bin
cd 
            
@rem **************************************************************************
@rem *  Single shot test to see if the NMC web server is already running
@rem **************************************************************************
set TCONSOLE_JAVAOPTS=%DEBUG% 

call tappNT .. com.tivoli.ihs.cli.nmcRunning %PORT%

if errorlevel 1 goto startNMC  

@rem **************************************************************************
@rem *  NMC is running, locate the specified resource
@rem **************************************************************************
:tryLocRes 

set TCONSOLE_JAVAOPTS=%DEBUG% 

call tappNT .. com.tivoli.ihs.cli.locRes %RES% %PORT%

goto done                  
                                                                                                              
@rem **************************************************************************
@rem *  Launch the NMC console forcing the start of the HTTP web server
@rem **************************************************************************
:startNMC

set TCONSOLE_JAVAOPTS=%ORIG_TCONSOLE_JAVAOPTS%

start %NV390_TCONSOLE_SCRIPT% .. -httpport %PORT% %ARGS%
       
@rem **************************************************************************
@rem *  Poll looking for the NMC web server to complete initialization
@rem **************************************************************************
set TCONSOLE_JAVAOPTS=-Dpoll %DEBUG% 

call tappNT .. com.tivoli.ihs.cli.nmcRunning %PORT%

if errorlevel 1 goto noNMC 

goto tryLocRes
                                               
@rem **************************************************************************
@rem *  Unable to connect to the NMC web server !!!
@rem **************************************************************************
:noNMC

@echo Unable to connect to the NMC console web server...

:done
