package examples;
import java.io.*;
import java.awt.*;
import java.lang.*;
import java.util.*;
import com.ibm.eNetwork.ECL.*;
import com.ibm.eNetwork.ECL.event.*;
import com.ibm.eNetwork.ECL.ECLScreenDesc;
import com.ibm.eNetwork.beans.HOD.*;
import java.awt.event.*;  
import src.ibmflb.*;


/*********************************************************************
 * This is a sample to issue a command in NetView FullScreen Session
   and search the screen
 */

public class FLB_ScreenSearchSample  extends Frame implements FLB_NVApplInterface, ECLPSListener
, WindowListener

{
   private ECLSession session;
   private FLB_NVApplListener listener;
   private char[] plane;
   private TextArea area = new TextArea(20,80);
   private ECLPS ps;
   private ECLOIA oia;
   private String searchWord ="ALERT";

   /*********************************************************************
   * Constructor for FLB_ScreenSearchSample
   */

   public  FLB_ScreenSearchSample()
   {
   }

   /*********************************************************************
   * Method called by NMC3270MC when the appl is initialized.
   * This method is defined as part of the FLB_NVApplInterface
   * Add your working code here
   */
   public void init(ECLSession session)
   {
      add(area);
      addWindowListener(this);
      // The session object is for the FullScreen session from where
      // HACL appl was started. For any other session object use
      // session=FLB_HACLhelper.getSession("NCCF");
      //Obtain Presentation space and Operator input area objects 
      ps = session.GetPS();   //Get PS
      oia = session.GetOIA(); // Get OIA
      try
      {
         //Identify the input screen
         ECLScreenDesc screen = new ECLScreenDesc();
         screen.AddString("NPDA");
         try
         {
            if(ps.WaitForScreen(screen,10))
            {
               // Register with the ECL that we want to be notified whenever the
               // screen is updated.  
               ps.RegisterPSEvent(this);
               //Wait for screen
               if(oia.WaitForInput(10))           // Wait for input
                  ps.SendKeys("ALD"+ps.ENTER_STR); //Issue command
               else
               {
                  ps.UnregisterPSEvent(this);       //Stop receiving screen updates
                  System.out.println("Timed out waiting for input.");
               }                                 
            }
            else  System.out.println("Timed out waiting Screen.");

         }
         catch(InterruptedException e)
         {
            System.out.println("Command interrupted.");
         }
      }
      catch(ECLErr err)
      //--------------------------------------------------------------------
      // Cause an 'invalid parameter' error and catch the ECLErr exception.
      // Then extract the error number and language-sensitive message text.
      //--------------------------------------------------------------------
      {
         System.out.println("ECLErr Exception  --> " + err.GetMsgText());
      }
   }

   // Whenever Screen updates this method will execute
   // Identify your screen you want to works with
   public void PSNotifyEvent(ECLPSEvent evt)
   {
      int pos;
      if(evt.GetType() == ECLPS.HOST_EVENTS)  //Get only Host events
      {
         try
         {

            int len  = ps.GetSize();
            int rows = ps.GetSizeRows();
            int cols = ps.GetSizeCols();

            plane = new char[len+1];   // Size of screen len plus 1 extra byte
            // Note text buffer needs extra byte for null terminator
            ps.GetScreen(plane, len, 1, len, ps.TEXT_PLANE);

            if((pos=ps.SearchText(searchWord, ps.SEARCH_FORWARD)) > 0)
            {
               area.append(" Target found at row "+ps.ConvertPosToRow(pos)+" and column "+ps.ConvertPosToCol(pos)+"\n");
               for(int row=0; row < rows; row++)
               {
                  //System.out.println(String.valueOf(plane, row*cols, cols));
                  String line =String.valueOf(plane, row*cols, cols);
                  area.append(line+"\n");
               }

            }
            else
               area.append(" Target not found\n");
            setBounds(0,0,400,400);
            show();
         }
         catch(ECLErr err)
         {System.out.println("ECLErr Exception  --> " + err.GetMsgText());
         }
      }
   }
   public void PSNotifyStop(ECLPS eclps, int reason)
   {
   }

   public void PSNotifyError(ECLPS eclps, ECLErr e)

   {
      System.out.println("ECLErr Exception  --> " + e.GetMsgText());

   }

   /******************************************************************************
   * Handles AWT Window events
   *
   * @param evt AWT WindowEvent
   *
   * @return void
   *
   * These methods are needed to implement the WindowListener interface in JDK 1.1
   *
   *
   ******************************************************************************/

   public void windowClosed(WindowEvent event) 
   {
   }

   public void windowDeiconified(WindowEvent event) 
   {
   }

   public void windowIconified(WindowEvent event) 
   {
   }

   public void windowActivated(WindowEvent event) 
   {
   }

   public void windowDeactivated(WindowEvent event) 
   {
   }
   public void windowOpened(WindowEvent event) 
   {
   }

   public void windowClosing(WindowEvent event) 
   {
      ps.UnregisterPSEvent(this);       //Stop receiving screen updates
      if(listener != null)              // Tell listener we are going away
         listener.applClosing(this);
      dispose();                        // Cleanup
   }

   /**
    * addListener
    * registers a Listener for this appl, this is required to notify
    * the appl when NetView sessions are going away

    */

   public void addListener( FLB_NVApplListener listener ){
      this.listener  = listener ;
   }

   /**      *****Important*****
   *       Must add code here to clean up and exit 
   *      Failure to do so may cause a session to hang
   */
   public void closeDown(){
      ps.UnregisterPSEvent(this);         
      dispose();                          // Cleanup

   }

   /**
    * removeListener
    * un-registers a Listener for this appl
    */

   public void removeListener( FLB_NVApplListener listener ){
      this.listener = null;

   }





}


